ProfileHeader class

Inheritance

Constructors

ProfileHeader({Key? key, String? imageSource, Color? imgBgColor, double avatarRadius = 20, String? titleTxt, TextStyle? titleTxtStyle, String? subTitleTxt, TextStyle? subTitleTxtStyle, Widget? titleWidget, Widget? subTitleWidget, bool centerTitle = false, EdgeInsetsGeometry? padding, Color textColor = Colors.white})
const

Properties

avatarRadius double
Radius for the avatar image.
final
centerTitle bool
Whether to center the row.
final
hashCode int
The hash code for this object.
no setterinherited
imageSource String?
Avatar image from URL or path (optional).
final
imgBgColor Color?
Background color for the avatar.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry?
Padding around the whole widget.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subTitleTxt String?
Optional subtitle string.
final
subTitleTxtStyle TextStyle?
Custom text style for subtitle.
final
subTitleWidget Widget?
Custom widget to override subtitle.
final
textColor Color
Text color if no custom style is provided.
final
titleTxt String?
Optional title string.
final
titleTxtStyle TextStyle?
Custom text style for title.
final
titleWidget Widget?
Custom widget to override title.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited